function samples = shGenerateSamples( sqrt_num_samples, max_band, ...
                                      sample_method)
%
% samples = shGenerateSamples( num_samples, max_band, sample_method)
%
% Generate (sqrt_num_samples)^2 uniformly distributed samples on the sphere
% \mathbb{S}^2
%
% @param  sample_method  method used for generating samples as described in
%                        uniformPointsS2()

  % default arguments
  defval( 'sample_method', 'halton-sphere');

  base_dir = './data';
  fname = [base_dir '/', 'sh_proj_samples'];
  fname = [fname, '_L', num2str(max_band)];
  fname = [fname, '_samples', num2str(sqrt_num_samples)];
  fname = [fname, '_', sample_method];
  
  try
    
    % try to load
    load( fname);
    
  catch

    samples = {};

    inv_n = 1.0 / sqrt_num_samples;
    i = 1;

    % create random samples
    samples_s2 = uniformPointsS2( sqrt_num_samples^2, sample_method);

    for( i = 1:size( samples_s2, 1))

      % current sample
      theta = samples_s2(i,1);
      phi = samples_s2(i,2);

      % create a new sample and store its spherical (sph) and cartesian (vec)
      % coordinates
      sample.sph = [theta, phi, 1.0];
      sample.vec = [sin(theta) * cos(phi), sin(theta) * sin(phi), cos( theta)];

      coeffs = [];

      % Evaluate all basis functions under consideration for the current
      % sample

      % for all bands 
      for( l = 0 : max_band)
        % for all basis functions within the band
        for( m = -l : l)

          index = l * (l+1) + m + 1;
          coeffs(index) = shEval( l, m, theta, phi);

        end  % end for all basis functions within a band
      end  % end for all bands

      % store function evaluations
      sample.coeffs = coeffs;
      % store the new sample
      samples{i} = sample;
      i = i + 1;

    end  
    
    % store compute transport operator
    save( fname, 'samples');
    
  end  % end catch

end