function coeffs = shProjectDiffuse( samples, max_band, exponent)
%
% coeffs = shProjectDiffuse( samples, num_bands, exponent)
%
% Project scaled local cosine term into Spherical Harmonics with max_bands
% bands.

  coeffs = zeros( 1, (max_band+1)^2);
  
  % do for all samples
  for( i = 1 : numel( samples))
    
    sample = samples{i};
    
    % compute scaled cosine term, restricted to the upper hemisphere
    if( sample.vec(3) > 0)
      cos_val = dot( [0,0,1], sample.vec)^exponent;    
    else 
      cos_val = 0;
    end
    
    % replicate for vectorized processing
    signal_sample = repmat( cos_val, 1, numel( sample.coeffs));

    % project for all bands simultaneously
    coeffs = coeffs + (sample.coeffs .* signal_sample);
    
  end

  % normalize
  factor = (4 * pi) / numel( samples);
  coeffs = coeffs * factor;
  
end
