function coeffs_r = shRotateRKHSSpectral( band_max, coeffs, R)
%
% coeffs_r = shRotateRKHSSpectral( band_max, coeffs, R)
%
% Rotate spherical harmonics coefficients using method by Gimbutas and
% Greengard.
%
% @return coeffs_r     The rotated SH coeffs
% @param  band_max    Maximum SH band
% @param  coeffs      Spherical Harmonics coefficients of the unrotated
%                     signal
% @param  R           rotation

 
  defval( 'fix_inaccuracies', 0);

  % initialize coefficients and in particular copy the zero-th band
  % coefficients which are invariant under rotation
  coeffs_r(:,1) = coeffs(:,1);
  
  for band = 1 : band_max

    % perform rotation for current band
    coeffs_band_r = shRotateRKHSSpectralL( band, coeffs, R);
    
    % store coefficients for current band
    coeffs_r = [coeffs_r  coeffs_band_r];
    
  end  % end for all bands

end