function R = getRotationMatrixAxisAngle( axis, theta)
%
% R = getRotationMatrixAxisAngle( axis, theta)
%
% Construct the rotation matrix given an axis and angle.
%
% @note The matrix is taken from Wikipedia,
% http://en.wikipedia.org/wiki/Rotation_matrix#Axis_and_angle

  theta = deg_to_rad( theta);
  x = axis(1);
  y = axis(2);
  z = axis(3);
  
  c = cos(theta); 
  s = sin(theta); 
  C = 1-c;

  xs = x*s;   ys = y*s;   zs = z*s;
  xC = x*C;   yC = y*C;   zC = z*C;
  xyC = x*yC; yzC = y*zC; zxC = z*xC;

  R = [ x*xC+c   xyC-zs   zxC+ys; ...
        xyC+zs   y*yC+c   yzC-xs; ...
        zxC-ys   yzC+xs   z*zC+c ];

end